@@ -111,7 +111,7 @@ class MergeMetric(sm.SegmentationMetrics):
         # Initialize mistake counters
         self.site_cnt = 0
         self.edge_cnt = 0
-        self.edge_list = {}
+        self.merged_edges = {}
 
         super().__init__(pred_graphs, target_volume, shape, output, output_dir)
 
@@ -142,21 +142,16 @@ class MergeMetric(sm.SegmentationMetrics):
                     self.site_cnt += 1
                     fn = "merge_site-" + str(self.site_cnt) + ".swc"
                     super().log_simple_mistake(graph, i, fn)
-                    dfs_edges, cnt1 = self.explore_merge(
-                        graph, dfs_edges, i, val_i
-                    )
-                    dfs_edges, cnt2 = self.explore_merge(
-                        graph, dfs_edges, j, val_j
-                    )
-                    self.edge_cnt += min(cnt1, cnt2) + 1
+                    dfs_edges = self.explore_merge(graph, dfs_edges, i, val_i)
+                    dfs_edges = self.explore_merge(graph, dfs_edges, j, val_j)
                 elif super().check_complex_mistake(val_i, val_j):
-                    print('complex')
                     dfs_edges = self.process_complex_mistake(
                         graph, dfs_edges, (i, j)
                     )
 
             # Save Results
             super().write_results("merge_")
+            self.edge_cnt = len(self.merged_edges) // 2
 
     def explore_merge(self, graph, dfs_edges, root, val):
         """
@@ -180,7 +175,7 @@ class MergeMetric(sm.SegmentationMetrics):
             List of merged edges.
 
         """
-        merged_edges = list()
+        cur_merge = list()
         visited = set()
         queue = [(-1, root)]  # parent, child
         while len(queue) > 0:
@@ -188,24 +183,25 @@ class MergeMetric(sm.SegmentationMetrics):
             i, j = queue.pop(0)
             val_i = utils.get_value(self.volume, graph, j)
             if val_i == val and i != -1:
+                self.merged_edges.update({(i, j), (j, i)})
+                cur_merge.append((i, j))
                 dfs_edges = utils.remove_edge(dfs_edges, (i, j))
-                self.edge_list.update({(i, j), (j, i)})
-                merged_edges.append((i, j))
             visited.add(j)
 
             # Populate queue
             for k in utils.get_nbs(graph, j):
                 condition1 = k not in visited
-                condition2 = (j, k) not in self.edge_list
+                condition2 = (j, k) not in self.merged_edges
                 if condition1 and condition2:
                     queue.append((j, k))
 
-        # Finalizations
-        if len(merged_edges) > 0:
-            fn = "merged_edges-" + str(self.site_cnt) + ".swc"
-            super().log_complex_mistake(graph, merged_edges, root, fn)
+        # Finalizations ~ edit this to output merged edges
+        if len(cur_merge) > 0:
+            edge_cnt = len(self.merged_edges) // 2
+            fn = "merged_edges-" + str(edge_cnt) + ".swc"
+            super().log_complex_mistake(graph, cur_merge, root, fn)
 
-        return dfs_edges, len(merged_edges)
+        return dfs_edges
 
     def process_complex_mistake(self, graph, dfs_edges, edge):
         """
@@ -242,15 +238,9 @@ class MergeMetric(sm.SegmentationMetrics):
             (i, j) = queue.pop(0)
             val_j = utils.get_value(self.volume, graph, j)
             if super().check_simple_mistake(val, val_j):
-                dfs_edges, cnt1 = self.explore_merge(
-                    graph, dfs_edges, root, val
-                )
-                dfs_edges, cnt2 = self.explore_merge(
-                    graph, dfs_edges, j, val_j
-                )
-                self.edge_cnt += min(cnt1, cnt2) + 1
                 self.site_cnt += 1
-
+                dfs_edges = self.explore_merge(graph, dfs_edges, root, val)
+                dfs_edges = self.explore_merge(graph, dfs_edges, j, val_j)
                 fn = "merge_site-" + str(self.site_cnt) + ".swc"
                 super().log_simple_mistake(graph, root, fn)
             elif val_j == 0:
